@@ -12,7 +12,7 @@ import (
 type Parser struct{}
 
 // Unmarshal unmarshals SPDX files.
-func (*Parser) Unmarshal(p []byte, v interface{}) error {
+func (*Parser) Unmarshal(p []byte, v any) error {
 	doc, err := tagvalue.Read(bytes.NewBuffer(p))
 	if err != nil {
 		return fmt.Errorf("error while parsing %v: %v", p, err)
@@ -20,7 +20,7 @@ func (*Parser) Unmarshal(p []byte, v interface{}) error {
 
 	out, err := json.Marshal(doc)
 	if err != nil {
-		return fmt.Errorf("error while marshalling %v: %v", p, err)
+		return fmt.Errorf("error while marshaling %v: %v", p, err)
 	}
 
 	if err := json.Unmarshal(out, v); err != nil {
